@@ -38,10 +38,11 @@ check_output "PEP8 checks"
 
 printf "\n${GREEN}${BOLD}All checks pass${NORMAL}${WHITE}\n\n"
 
+echo "*********** Integration tests **********"
+python tests/integration/inte_logger.py
+python tests/integration/inte_two_loggers.py
+
 echo "*********** Style evaluation ***********"
 score=$(pylint . | sed -n 's/^Your code has been rated at \([-0-9.]*\)\/.*/\1/p')
 
 echo "Pylint score: ${BOLD}$score/10.0${NORMAL} (details by running: pylint .)\nMinimum authorized score: 8.5\n"
-
-echo "*********** Integration tests **********"
-python tests/integration/logger.py
